/*
 * This file was generated by qdbusxml2cpp version 0.7
 * Command line was: qdbusxml2cpp -N -p fcitxqtinputcontextproxyimpl -c
 * FcitxQtInputContextProxyImpl interfaces/org.fcitx.Fcitx.InputContext1.xml -i
 * fcitxqtdbustypes.h -i fcitx5qt4dbusaddons_export.h
 *
 * qdbusxml2cpp is Copyright (C) 2015 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#include "fcitxqtinputcontextproxyimpl.h"

namespace fcitx {

/*
 * Implementation of interface class FcitxQtInputContextProxyImpl
 */

FcitxQtInputContextProxyImpl::FcitxQtInputContextProxyImpl(
    const QString &service, const QString &path,
    const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection,
                             parent) {}

FcitxQtInputContextProxyImpl::~FcitxQtInputContextProxyImpl() {}
} // namespace fcitx
